/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

package org.kie.internal.task.api;

import org.kie.api.runtime.Context;
import org.kie.api.task.UserGroupCallback;

public interface TaskContext extends Context, org.kie.api.task.TaskContext {

    TaskPersistenceContext getPersistenceContext();

    void setPersistenceContext(TaskPersistenceContext context);

    UserGroupCallback getUserGroupCallback();

}
